pub struct CachedPackageStore<'state, 'runtime> {
pub package_store: TransactionPackageStore<'state>,
/* private fields */
}Expand description
The CachedPackageStore is a PackageStore implementation that uses a MoveRuntime to
fetch and cache packages. It also uses an underlying TransactionPackageStore to fetch packages
that are not in the cache. This is used to provide package loading (from storage)
for the Move VM, while also allowing for packages that are being published in the
current transaction to be found.
Fields
package_store: TransactionPackageStore<'state>Underlying store to fetch packages from. Any newly published packages in the current
transaction should be in the new_packages field of this store.
Implementations
Sourceimpl<'state, 'runtime> CachedPackageStore<'state, 'runtime>
impl<'state, 'runtime> CachedPackageStore<'state, 'runtime>
pub fn new( runtime: &'runtime MoveRuntime, package_store: TransactionPackageStore<'state>, ) -> Self
Sourcepub fn get_package(
&self,
object_id: &ObjectID,
) -> SuiResult<Option<Arc<VerifiedPackage>>>
pub fn get_package( &self, object_id: &ObjectID, ) -> SuiResult<Option<Arc<VerifiedPackage>>>
Get a package by its package ID (i.e., not original ID). This will first look in the new packages, and then fetch the pacakge from the underlying Move runtime which handles loading and caching of packages. If the package is not found, None is returned. If there is an error fetching the package, an error is returned.
Once the package is fetched it is in the Move runtime cache, and will be found there on subsequent lookups.
pub fn get_move_package( &self, object_id: &ObjectID, ) -> SuiResult<Option<Rc<MovePackage>>>